#ifndef NT2_INCLUDE_FUNCTIONS_JNI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_JNI_HPP_INCLUDED

#include <nt2/bessel/include/functions/jni.hpp>

#endif
